==> zio-aws-ec2_2.12-5.17.269.1-sources.jar: zio/aws/ec2/model/DisableVpcClassicLinkDnsSupportResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DisableVpcClassicLinkDnsSupportResponse(
    returnValue: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkDnsSupportResponse = {
    import DisableVpcClassicLinkDnsSupportResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkDnsSupportResponse
      .builder()
      .optionallyWith(returnValue.map(value => value: java.lang.Boolean))(
        _.returnValue
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DisableVpcClassicLinkDnsSupportResponse.ReadOnly =
    zio.aws.ec2.model.DisableVpcClassicLinkDnsSupportResponse
      .wrap(buildAwsValue())
}
object DisableVpcClassicLinkDnsSupportResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkDnsSupportResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DisableVpcClassicLinkDnsSupportResponse =
      zio.aws.ec2.model.DisableVpcClassicLinkDnsSupportResponse(
        returnValue.map(value => value)
      )
    def returnValue: Optional[Boolean]
    def getReturnValue: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("returnValue", returnValue)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkDnsSupportResponse
  ) extends zio.aws.ec2.model.DisableVpcClassicLinkDnsSupportResponse.ReadOnly {
    override val returnValue: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.returnValue())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkDnsSupportResponse
  ): zio.aws.ec2.model.DisableVpcClassicLinkDnsSupportResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.123.1-sources.jar: zio/aws/ec2/model/DisableVpcClassicLinkDnsSupportResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DisableVpcClassicLinkDnsSupportResponse(
    returnValue: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkDnsSupportResponse = {
    import DisableVpcClassicLinkDnsSupportResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkDnsSupportResponse
      .builder()
      .optionallyWith(returnValue.map(value => value: java.lang.Boolean))(
        _.returnValue
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DisableVpcClassicLinkDnsSupportResponse.ReadOnly =
    zio.aws.ec2.model.DisableVpcClassicLinkDnsSupportResponse
      .wrap(buildAwsValue())
}
object DisableVpcClassicLinkDnsSupportResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkDnsSupportResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DisableVpcClassicLinkDnsSupportResponse =
      zio.aws.ec2.model.DisableVpcClassicLinkDnsSupportResponse(
        returnValue.map(value => value)
      )
    def returnValue: Option[Boolean]
    def getReturnValue: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("returnValue", returnValue)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkDnsSupportResponse
  ) extends zio.aws.ec2.model.DisableVpcClassicLinkDnsSupportResponse.ReadOnly {
    override val returnValue: Option[Boolean] =
      scala.Option(impl.returnValue()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkDnsSupportResponse
  ): zio.aws.ec2.model.DisableVpcClassicLinkDnsSupportResponse.ReadOnly =
    new Wrapper(impl)
}
